import SkribblClient from "../logic/SkribblClient.js";
import {CustomElement} from "../util/Util.js";

/**
 * Custom element `<skribbl-canvas>` for the canvas that can be drawn on by whoever is currently drawing.
 */
export default class SkribblCanvas extends CustomElement {
	/**
	 * @param {SkribblClient} client 
	 */
	constructor(client){
		super();
		this._drawable = false;
		this.attachShadow({mode:"open"});
		this.shadowRoot.innerHTML = `
			<style>
				:host {
					display: block;
					width: 100%;
					height: 100%;
				}
				canvas {
					width: 100%;
					height: 100%;
				}
			</style>
			<canvas width="960" height="720"></canvas>
		`;
		this._canvas = this.shadowRoot.querySelector("canvas");
		client.onDraw(order=>{
			// runs whenever the server tells all clients to draw something on the canvas
			// TODO draw stuff to the canvas here
			console.log("incoming draw order:",order); // just for testing, can be removed once this has been implemented
		},{onlyWhen:this.connected});
		// TODO whenever the player draws stuff, send it to the server using `client.draw(order)` here
		this._canvas.addEventListener("mousedown",e=>{
			// for example, this code runs whenever the user clicks on the canvas. "mousemove", "mouseup", "mouseenter" and "mouseleave" events can be monitored similarly.
		});
	}

	/**
	 * Whether the canvas can currently be drawn on by this player.
	 */
	set drawable(drawable){
		if (this._drawable!==drawable){
			this._drawable = drawable;
			// if some styles need to be changed depending on whether or not the player is currently allowed to draw, like the mouse coursor for example, this is probably the right place to do so
		}
	}

	get drawable(){
		return this._drawable;
	}

	// TODO add getters and setters for properties like `color` and `radius` here, so they can then be set in `SkribblCanvasContainer.js` whenever the user clicks on the corresponding controls.
}
customElements.define("skribbl-canvas",SkribblCanvas);